Index: /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCLogParser.java
===================================================================
--- /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCLogParser.java	(revision 1008)
+++ /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCLogParser.java	(revision 1009)
@@ -108,5 +108,5 @@
     /**
      * <p>
-     * internal handle to the parameters currently parsed for a component
+     * internal handle to the GUI element specification currently parsed for a GUI element
      * </p>
      */
@@ -115,5 +115,5 @@
     /**
      * <p>
-     * internal handle to the last parsed component
+     * internal handle to the last parsed GUI element
      * </p>
      */
@@ -122,5 +122,5 @@
     /**
      * <p>
-     * internal handle to the component of the previous event to be potentially reused for the
+     * internal handle to the GUI element of the previous event to be potentially reused for the
      * current
      * </p>
@@ -148,6 +148,4 @@
      * </p>
      * 
-     * @author Steffen Herbold
-     * @version 1.0
      */
     private enum ParamSource {
@@ -396,5 +394,5 @@
                 if (currentGuiElementPath.size() <= 0)
                 {
-                    // no component specification available. Try to parse the GUI element from
+                    // no GUI element specification available. Try to parse the GUI element from
                     // the toString parameter
                     currentGuiElementSpec = new JFCGUIElementSpec();
@@ -631,5 +629,5 @@
     /**
      * <p>
-     * for some events in the log file, no component specification is provided. In this case the
+     * for some events in the log file, no GUI element specification is provided. In this case the
      * GUI element on which the event is executed must be determined based on the
      * <code>toString</code> parameter of the event. This is achieved through this method. The
@@ -642,5 +640,5 @@
      *            the <code>toString</code> parameter of the event to be parsed for the GUI element
      *            
-     * @return the appropriate GUI Element
+     * @return the appropriate GUI element
      * 
      * @throws SAXException thrown if the provided value of the <code>toString</code> parameter
Index: /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCSimplifiedLogParser.java
===================================================================
--- /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCSimplifiedLogParser.java	(revision 1008)
+++ /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCSimplifiedLogParser.java	(revision 1009)
@@ -42,5 +42,4 @@
 import de.ugoe.cs.autoquest.keyboardmaps.VirtualKey;
 import de.ugoe.cs.autoquest.plugin.jfc.eventcore.JFCEventId;
-import de.ugoe.cs.autoquest.plugin.jfc.guimodel.JFCComponentTree;
 import de.ugoe.cs.autoquest.plugin.jfc.guimodel.JFCGUIElement;
 import de.ugoe.cs.autoquest.plugin.jfc.guimodel.JFCGUIElementSpec;
@@ -76,13 +75,13 @@
      * 
      * <p>
-     * Internal handle to the hashcode of the component, that is currently parsed.
-     * </p>
-     */
-    private Long currentComponentHash;
+     * Internal handle to the hashcode of the GUI element, that is currently parsed.
+     * </p>
+     */
+    private Long currentGUIElementHash;
     
     /**
      * 
      * <p>
-     * Internal handle to the hashcode of the parent of the component, that is currently parsed. 
+     * Internal handle to the hashcode of the parent of the GUI element, that is currently parsed. 
      * </p>
      */
@@ -118,5 +117,5 @@
     /**
      * <p>
-     * internal handle to the parameters currently parsed for a component
+     * internal handle to the specification currently parsed for a GUI element
      * </p>
      */
@@ -125,5 +124,5 @@
     /**
      * <p>
-     * internal handle to the parsed gui structure, stored in a JFCComponentTree
+     * internal handle to the parsed GUI structure, stored in a GUIElementTree
      * </p>
      */
@@ -132,5 +131,5 @@
     /**
      * <p>
-     * internal handle to the component of the previous event to be potentially reused for the
+     * internal handle to the GUI element of the previous event to be potentially reused for the
      * current
      * </p>
@@ -288,5 +287,5 @@
     /**
      * <p>
-     * Returns the gui model that is obtained from parsing log files.
+     * Returns the GUI model that is obtained from parsing log files.
      * </p>
      * 
@@ -319,7 +318,7 @@
         }
         else if (qName.equals("component")) {
-        	currentComponentHash = Long.parseLong(atts.getValue("hash"), 16);
+        	currentGUIElementHash = Long.parseLong(atts.getValue("hash"), 16);
         	currentGuiElementSpec = new JFCGUIElementSpec();
-        	currentGuiElementSpec.setElementHash((int) currentComponentHash.longValue());
+        	currentGuiElementSpec.setElementHash((int) currentGUIElementHash.longValue());
         }
         else if (qName.equals("event")) {
@@ -347,5 +346,5 @@
         		}
                 currentEventParameters.put(atts.getValue("name"), atts.getValue("value"));
-            } else if(currentComponentHash != null){
+            } else if(currentGUIElementHash != null){
             	if ("title".equals(atts.getValue("name"))) {
         			currentGuiElementSpec.setName(atts.getValue("value"));
@@ -390,9 +389,9 @@
         	currentGuiElementSpec.setTypeHierarchy(currentTypeHierarchy);
         }
-        else if (qName.equals("component") && currentComponentHash != null) {
-        	currentGUIElementTree.add(currentComponentHash, currentParentHash, currentGuiElementSpec);
+        else if (qName.equals("component") && currentGUIElementHash != null) {
+        	currentGUIElementTree.add(currentGUIElementHash, currentParentHash, currentGuiElementSpec);
         	// do something with the ancestor list here
         	
-        	currentComponentHash = null;
+        	currentGUIElementHash = null;
         	currentParentHash = null;
         	currentTypeHierarchy = null;
@@ -609,5 +608,5 @@
     /**
      * <p>
-     * for some events in the log file, no component specification is provided. In this case the
+     * for some events in the log file, no GUI element specification is provided. In this case the
      * GUI element on which the event is executed must be determined based on the
      * <code>toString</code> parameter of the event. This is achieved through this method. The
Index: /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/guimodel/JFCGUIElementSpec.java
===================================================================
--- /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/guimodel/JFCGUIElementSpec.java	(revision 1008)
+++ /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/guimodel/JFCGUIElementSpec.java	(revision 1009)
@@ -77,5 +77,5 @@
     /**
      * <p>
-     * Hash code of the window element. Used as unique identifier during its existence.
+     * Hash code of the GUI element. Used as unique identifier during its existence.
      * </p>
      */
@@ -84,5 +84,5 @@
     /**
      * <p>
-     * Previous hashes of the window as the window may have been destroyed and recreated.
+     * Previous hashes of the GUI element as the GUI element may have been destroyed and recreated.
      * </p>
      */

Index: /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCReplayIDCalculator.java
===================================================================
--- /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCReplayIDCalculator.java	(revision 1008)
+++ /trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCReplayIDCalculator.java	(revision 1009)
@@ -77,5 +77,5 @@
    /**
     * Calculates the replayID of a JFCEvent needed for compatibility with guitar suite
-    * @param List of {@link JFCGUIElementSpec}s that represent the component path of a event target
+    * @param List of {@link JFCGUIElementSpec}s that represent the path of an event target
     * for which the replayID should be calculated. 
     * @return replayID
@@ -91,17 +91,17 @@
 	   String title = currentSpec.getName();
 	   String fuzzyTitle = getFuzzyTitle(title);
-	   long windowHashCode = fuzzyTitle.hashCode();
-	   windowHashCode = (windowHashCode * 2) & 0xffffffffL;
-
-	   long propagatedHashCode = windowHashCode;
+	   long topLevelHashCode = fuzzyTitle.hashCode();
+	   topLevelHashCode = (topLevelHashCode * 2) & 0xffffffffL;
+
+	   long propagatedHashCode = topLevelHashCode;
 	   
-	   // added validator to check if generated component ids are known
+	   // added validator to check if generated GUI element ids are known
 	   if (validator != null){
-		   if (validator.validateReplayID("w" + windowHashCode)){
-			   System.out.println("ID w" + windowHashCode + " is valid.");
+		   if (validator.validateReplayID("w" + topLevelHashCode)){
+			   System.out.println("ID w" + topLevelHashCode + " is valid.");
 		   }
 		   else{
-			   System.err.println(currentSpec + " describes an unknown component.");
-		   	   System.err.println("ID w" + windowHashCode + " is unknown." );
+			   System.err.println(currentSpec + " describes an unknown GUI element.");
+		   	   System.err.println("ID w" + topLevelHashCode + " is unknown." );
 		   	   System.err.println();
 		   }
@@ -114,9 +114,9 @@
 	   else{
 		   currentSpec = null;
-		   // there are no subcomponents, so we use windowHashCode as hashCode
-		   hashCode = windowHashCode;
+		   // there are no children of current GUI element, so we use topLevelHashCode as hashCode
+		   hashCode = topLevelHashCode;
 	   }
 
 	   // walk through component path and calculate hashcode
 	   while(currentSpec != null){
 		   long localHashCode = getLocalHashCode(currentSpec);
@@ -124,13 +124,13 @@
 		   hashCode = (hashCode * 2) & 0xffffffffL;
 		   
-		   // added validator to check if generated component ids are known
+		   // added validator to check if generated GUI element ids are known
 		   if (validator != null){
 			   if (validator.validateReplayID("w" + hashCode)){
 				   System.out.println("ID w" + hashCode + " is valid.");
-				   System.out.println("==> " + currentSpec + " describes a known component.");
+				   System.out.println("==> " + currentSpec + " describes a known GUI element.");
 			   }
 			   else{
 				   System.err.println("ID w" + hashCode + " is unknown." );
-				   System.err.println("==> " + currentSpec + " describes an unknown component.");
+				   System.err.println("==> " + currentSpec + " describes an unknown GUI element.");
 				   System.err.println();
 			   }
@@ -183,5 +183,5 @@
 	
 	/**
 	 * Calculates the hashcode part of a component.
 	 * @param spec The {@link JFCGUIElementSpec} for which the hashcode should be calculated.
 	 * @return the local hashcode
@@ -238,6 +238,6 @@
 	
 	/**
 	 * Guitar has a special way to deal with window titles when
 	 * calculating unique widget IDs. This method mimics Guitar's
 	 * behavior (compare guitar source code: edu.umd.cs.guitar.
 	 * model.JFCDefaultIDGeneratorSimple).
@@ -114,9 +114,9 @@
 	   }
 
-	   // walk through component path and calculate hashcode
+	   // walk through GUI element path and calculate hashcode
 	   while(currentSpec != null){
 		   long localHashCode = getLocalHashCode(currentSpec);
@@ -183,5 +183,5 @@
 	
 	/**
-	 * Calculates the hashcode part of a component.
+	 * Calculates the hashcode part of a GUI element.
 	 * @param spec The {@link JFCGUIElementSpec} for which the hashcode should be calculated.
 	 * @return the local hashcode
@@ -238,6 +238,6 @@
 	
 	/**
-	 * Guitar has a special way to deal with window titles when
-	 * calculating unique widget IDs. This method mimics Guitar's
+	 * Guitar has a special way to deal with top level GUI elements (window) 
+	 * titles when calculating unique widget IDs. This method mimics Guitar's
 	 * behavior (compare guitar source code: edu.umd.cs.guitar.
 	 * model.JFCDefaultIDGeneratorSimple).